<?php
require_once APPLICATION_PATH . '/models/DbTable/Users.php';

class Model_Users {
    protected $_table;
	
	public function fetchAll($orderby="denominazione",$orderdir="desc")
    {
		$table=new Users();
		$select = $table->select()->order($orderby.' '.$orderdir);
        return $table->fetchAll($select);
    }
 
	public function fetchEntries($orderby="denominazione",$orderdir="desc")
    {
		$table=new Users();
		$select = $table->select()->order($orderby.' '.$orderdir);
        return $table->fetchAll($select)->toArray();
    }
	
	 
    public function fetchEntry($id)
    {
        $table = new Users();
        $select = $table->select()->where('id = ?', $id);
		$select=$table->fetchRow($select);
		if($select)
        	return $select->toArray();
		else
			return null;
    }
	
	public function deleteMessage($msgid)
    {
        $table=new Messages();
		$where=$table->getAdapter()->quoteInto('id = ?', $msgid);
		return $table->delete($where);
    }
	
	public function sendMessage(array $data)
    {
		$table=new Messages();
        $fields = $table->info(Zend_Db_Table_Abstract::COLS);
		foreach ($data as $field => $value) {
            if (!in_array($field, $fields)) {
                unset($data[$field]);
            }
        }
		$table->insert($data);
		
        return $table->getAdapter()->lastInsertId();
    }
	
	public function getMessages($userid)
    {
        $table = new Messages();
        $select = $table->select()->where('id_utente = ?', $userid)->order("data DESC");
        return $table->fetchAll($select)->toArray();
    }
	
	public function deleteNote($noteid)
    {
        $table=new Note();
		$where=$table->getAdapter()->quoteInto('id = ?', $noteid);
		return $table->delete($where);
    }
	
	public function newNote(array $data)
    {
        $table=new Note();
        $fields = $table->info(Zend_Db_Table_Abstract::COLS);
        foreach ($data as $field => $value) {
            if (!in_array($field, $fields)) {
                unset($data[$field]);
            }
        }
		
		$table->insert($data);
		
        return $table->getAdapter()->lastInsertId();
    }
	
	public function getNote($userid)
    {
        $table = new Note();
        $select = $table->select()->where('id_utente = ?', $userid)->order("id DESC");
        return $table->fetchAll($select)->toArray();
    }
	
	public function getRoleById($roleid)
    {
        $table = new Roles();
        $select = $table->select()->where('id = ?', $roleid);
        return $table->fetchRow($select)->toArray();
    }
	
	public function getRoleByCode($rolecode)
    {
        $table = new Roles();
        $select = $table->select()->where('codice = ?', $rolecode);
		return $table->fetchAll($select)->toArray();
    }
	
	public function getRoles()
    {
		$table=new Roles();
        return $table->fetchAll()->toArray();
    }
	
	public function getUsersByCreator($id,$orderby="denominazione",$orderdir="desc")
    {
        $table = new Users();
        $select = $table->select()->where('id_creatore = ?', $id)->order($orderby.' '.$orderdir);
        return $table->fetchAll($select)->toArray();
    }
	
	public function getUsersByName($name,$userid="",$orderby="denominazione",$orderdir="desc")
    {
        $table = new Users();
		if($userid!=""){
        	$select = $table->select()->where('id_creatore = ?', $userid)->where('denominazione LIKE ?', '%'.$name.'%')->order($orderby.' '.$orderdir);
		}else
			$select = $table->select()->where('denominazione LIKE ?', '%'.$name.'%')->order($orderby.' '.$orderdir);
        return $table->fetchAll($select)->toArray();
    }
	
	public function getUsersByUsername($username,$userid="")
    {
        $table = new Users();
		if($userid!=""){
        	$select = $table->select()->where('id_creatore = ?', $userid)->where('username = ?', $username);
		}else
			$select = $table->select()->where('username = ?', $username);
        return $table->fetchAll($select)->toArray();
    }
	
	public function getUsersByRole($roleid,$orderby="denominazione",$orderdir="desc")
    {
		$table=new Roles();
        $roleRowset=$table->find($roleid);
		$role=$roleRowset->current();
		
		$tableUsers=new Users();
		if($orderby=='id')
			$orderby='i.id';
		$select=$tableUsers->select()->order($orderby.' '.$orderdir);
		
		$usersRowset=$role->findManyToManyRowset('Users','RolesUsers',NULL,NULL,$select);
		
		$rsArray=$usersRowset->toArray();
		
		return $rsArray;
    }
	
	public function getWasteByUser($userid)
    {
		$table=new Users();
        $userRowset=$table->find($userid);
		$user=$userRowset->current();
		
		$wasteRowset=$user->findManyToManyRowset('UWaste','WasteUsers');
		
		$rsArray=$wasteRowset->toArray();
		
		return $rsArray;
    }
	
	public function getTransByUser($userid)
    {
	
		$table=new Users();
		
		
		$select = $table->select()->setIntegrityCheck(false);
		$select = $select->from('utenti')
						 ->join('utente_trasportatori','utente_trasportatori.id_utente=utenti.id')
						 ->join('utenti as tras','utente_trasportatori.id_trasportatore=tras.id',array('tras.id','tras.denominazione'))
						 ->where('utente_trasportatori.id_utente = ?', $userid);
        $rsArray=$table->fetchAll($select)->toArray();
		
		return $rsArray;
    }
	
	public function getDestByUser($userid)
    {
	
		$table=new Users();
		
		
		$select = $table->select()->setIntegrityCheck(false);
		$select = $select->from('utenti')
						 ->join('utente_destinatari','utente_destinatari.id_utente=utenti.id')
						 ->join('utenti as dest','utente_destinatari.id_destinatario=dest.id',array('dest.id','dest.denominazione'))
						 ->where('utente_destinatari.id_utente = ?', $userid);
        $rsArray=$table->fetchAll($select)->toArray();
		
		return $rsArray;
    }
	
	public function getDefaultValueByUserAndWaste($userid,$wasteid)
    {
		$table = new WasteUsers();
        $select = $table->select()->where('id_utente = ?', $userid)->where('id_rifiuto = ?', $wasteid);
		if($table->fetchRow($select))
			$rsArray= $table->fetchRow($select)->toArray();
		else
			$rsArray["default"]=0;
		return $rsArray["default"];
    }
	
	public function getRolesByUser($userid)
    {
		$table=new Users();
        $userRowset=$table->find($userid);
		$user=$userRowset->current();
		
		$rolesRowset=$user->findManyToManyRowset('Roles','RolesUsers');
		
		$rsArray=$rolesRowset->toArray();
		
		return $rsArray;
    }
	
	public function getActiveRoles($rsArray)
	{
		$roles=array();
		foreach($rsArray as $role){
			$roles[$role['codice']]=true;
		}
		
		return $roles;
	}
	
	public function getActiveWaste($rsArray)
	{
		$waste=array();
		foreach($rsArray as $item){
			$waste[$item['cer']]=true;
		}
		
		return $waste;
	}
	
	public function save(array $data,$userid)
    {
        $table=new Users();
        $fields = $table->info(Zend_Db_Table_Abstract::COLS);
        foreach ($data as $field => $value) {
            if (!in_array($field, $fields)) {
                unset($data[$field]);
            }
        }
		
		$data['data_attivazione']=date('Y-m-d');
		$data['data_ultima_modifica']=date('Y-m-d');
		$data['id_creatore']=$userid;
		$table->insert($data);
		
        return $table->getAdapter()->lastInsertId();
    }
	
	public function saveRoles($userid,array $data)
    {
        $table=new RolesUsers();
		$roles=array();
		foreach($data as $role){
			$roles['id_utente']=$userid;
			$roles['id_ruolo']=$role['id'];
			$table->insert($roles);
		}
    }
	
	public function saveWaste($userid,array $data)
    {
        $table=new WasteUsers();
		$waste=array();
		foreach($data as $item){
			$waste['id_utente']=$userid;
			$waste['id_rifiuto']=$item;
			$table->insert($waste);
		}
    }
	
	
	public function saveTrans($userid,array $data)
    {
        $table=new TransUsers();
		$trans=array();
		foreach($data as $item){
			$trans['id_utente']=$userid;
			$trans['id_trasportatore']=$item;
			$table->insert($trans);
		}
    }
	
	public function saveDest($userid,array $data)
    {
        $table=new DestUsers();
		$dest=array();
		foreach($data as $item){
			$dest['id_utente']=$userid;
			$dest['id_destinatario']=$item;
			$table->insert($dest);
		}
    }
	
	public function modify(array $data,$userid,$modifierid)
    {
        $table=new Users();
        $fields = $table->info(Zend_Db_Table_Abstract::COLS);
        foreach ($data as $field => $value) {
            if (!in_array($field, $fields)) {
                unset($data[$field]);
            }
        }
		
		$data['data_ultima_modifica']=date('Y-m-d');
		$data['id_modificatore']=$modifierid;
		$where=$table->getAdapter()->quoteInto('id = ?', $userid);
		return $table->update($data,$where);
    }
	
	public function descreasePage($pages,$userid)
    {
        $table=new Users();
		$select = $table->select()->where('id = ?', $userid);
		$select=$table->fetchRow($select);
		$data=$select->toArray();
		$data['pagine_libro']=$data['pagine_libro']-$pages;
		$where=$table->getAdapter()->quoteInto('id = ?', $userid);
		return $table->update($data,$where);
    }
	
	public function delete($userid)
    {
        $table=new Users();
		$where=$table->getAdapter()->quoteInto('id = ?', $userid);
		return $table->delete($where);
    }
	
	public function modifyRoles($userid,array $data)
    {
        $table=new RolesUsers();
		$where=$table->getAdapter()->quoteInto('id_utente = ?', $userid);
        $table->delete($where);
		$roles=array();
		foreach($data as $role){
			$roles['id_utente']=$userid;
			$roles['id_ruolo']=$role['id'];
			$table->insert($roles);
		}
    }
	
	public function modifyWaste($userid,array $data)
    {
        $table=new WasteUsers();
		$where=$table->getAdapter()->quoteInto('id_utente = ?', $userid);
		$waste=array();
		
		foreach($data as $item){
			$default[$item]=$this->getDefaultValueByUserAndWaste($userid,$item);
		}

        $table->delete($where);
		foreach($data as $item){
			$waste['id_utente']=$userid;
			$waste['id_rifiuto']=$item;
			$waste['default']=$default[$item];
			$table->insert($waste);
		}
    }
	
	public function modifyTrans($userid,array $data)
    {
        $table=new TransUsers();
		$where=$table->getAdapter()->quoteInto('id_utente = ?', $userid);
		$trans=array();
        $table->delete($where);
		foreach($data as $item){
			$trans['id_utente']=$userid;
			$trans['id_trasportatore']=$item;
			$table->insert($trans);
		}
    }
	
	public function modifyDest($userid,array $data)
    {
        $table=new DestUsers();
		$where=$table->getAdapter()->quoteInto('id_utente = ?', $userid);
		$dest=array();
        $table->delete($where);
		foreach($data as $item){
			$dest['id_utente']=$userid;
			$dest['id_destinatario']=$item;
			$table->insert($dest);
		}
    }
	
	public function updateWaste($userid,$wasteid,$default)
    {
        $table=new WasteUsers();
		$select = $table->getAdapter()->quoteInto('id_rifiuto = \''.$wasteid.'\' AND id_utente = ?', $userid);
		$data['default']=$default;
		return $table->update($data,$select);
		
    }
}

?>